@@ -1,9 +1,10 @@
-
-import utils.dir as directory
-import utils.file as file
-import ftputil
-
 # pylint: disable=too-many-branches
+# pylint: disable=unused-import
+# pylint: disable=line-too-long
+import ftputil
+import utils.dir as directory
+# import utils.file as file
+from utils import file
 
 
 def ftp_connect(address, user_name=None, password=None):
