@@ -225,11 +225,10 @@ def delete(file_path, **kwargs):
     min_thread_threshold = obj.get_kwarg(["min thread threshold", "min files thread"], 100, (int), **kwargs)
 
     file_list = _gen_path_list(file_path)
-    # print("file_list: ", json.dumps(file_list, indent=4))
+    print("file_list: ", json.dumps(file_list, indent=4))
     # exit()
     if len(file_list) > 0:
-
-        if threading is True and len(file_list) >= min_thread_threshold:
+        if threading is True and len(file_list) >= min_thread_threshold and ftp is None:
             _thread_file_action(file_list, action="delete", max_threads=max_threads, min_thread_threshold=min_thread_threshold, shred=shred, ftp=ftp)
             return
 
@@ -238,6 +237,7 @@ def delete(file_path, **kwargs):
                 if 'file_path' in file:
                     _delete_single_file(file['file_path'], shred, ftp)
             if isinstance(file, (str)):
+                print(f"_delete_single_file")
                 _delete_single_file(file, shred, ftp)
     return True
 
@@ -270,23 +270,19 @@ def _gen_path_list(file_obj):
     file_list = []
 
     if isinstance(file_obj, (str)) is True:
-        if exists(file_obj):
-            file_list.append(file_obj)
+        file_list.append(file_obj)
 
     if isinstance(file_obj, (list)) is True:
         for file in file_obj:
             if isinstance(file, (str)) is True:
-                if exists(file):
-                    file_list.append(file)
+                file_list.append(file)
             if isinstance(file, (dict)) is True:
                 if "file_path" in file:
-                    if exists(file["file_path"]):
-                        file_list.append(file["file_path"])
+                    file_list.append(file["file_path"])
 
     if isinstance(file_obj, (dict)) is True:
         if "file_path" in file_obj:
-            if exists(file_obj["file_path"]):
-                file_list.append(file_obj["file_path"])
+            file_list.append(file_obj["file_path"])
     return file_list
 
 
@@ -532,21 +528,23 @@ def _delete_single_file(file_path, shred=False, ftp=None):
         `method_name`: _delete_single_file
     '''
     success = False
-    if ftp.path.exists(file_path) is True:
-        ftp.remove(file_path)
-        return
-    if exists(file_path) is True:
-        try:
-            if shred is True:
-                secure_delete.secure_random_seed_init()
-                secure_delete.secure_delete(file_path)
-            else:
-                os.remove(file_path)
-        except PermissionError as error:
-            print(f"Failed to delete {file_path}, {error}")
-            success = True
+    if ftp is not None:
+        # print(f"file.delete.file_path: {file_path}")
+        if exists(file_path, ftp=ftp) is True:
+            ftp.remove(file_path)
     else:
-        success = True
+        if exists(file_path) is True:
+            try:
+                if shred is True:
+                    secure_delete.secure_random_seed_init()
+                    secure_delete.secure_delete(file_path)
+                else:
+                    os.remove(file_path)
+            except PermissionError as error:
+                print(f"Failed to delete {file_path}, {error}")
+                success = True
+        else:
+            success = True
 
     if exists(file_path) is False:
         success = False
@@ -657,7 +655,9 @@ def get_data(file_path, **kwargs):
     if ftp is not None:
         file_data = {}
         path = strUtils.format.file_path(file_path, url=True)
-        lstat = ftp.path.lstat(path)
+        # print(f"file.get_data.path:{path}")
+        # print(f"ftp: {ftp.path}")
+        lstat = ftp.lstat(path)
         file_data['file_path'] = path
         file_data['file_name'] = ftp.path.basename(path)
         file_data['extension'] = get_ext(path)
@@ -1101,7 +1101,7 @@ def get_files(search_path=False, **kwargs):
 
     ftp = obj.get_kwarg(["ftp"], None, None, **kwargs)
     if ftp is not None:
-        return directory.get_folders_ftp(search_path, **kwargs)
+        return get_files_ftp(search_path, **kwargs)
 
     if threaded is True:
         for path in search_path:
